==> haskell-ghc-tcplugins-extra-0.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-BKajd1hDiDoL8yI1MbhKZH
key: ghc-tcplugins-extra-0.3-BKajd1hDiDoL8yI1MbhKZH
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: 1deef78b6d7dd0dda16d4a6b75f1e289
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.6.2/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.6.2/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-BKajd1hDiDoL8yI1MbhKZH
depends:
    base-4.12.0.0 ghc-8.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-tcplugins-extra-0.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-ILrmwD6AoOJA69cuvx3Bhr
key: ghc-tcplugins-extra-0.3-ILrmwD6AoOJA69cuvx3Bhr
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: 21fcc6faba80b667d9228dbfab6fc1ab
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.6.3/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-ILrmwD6AoOJA69cuvx3Bhr
depends:
    base-4.12.0.0 ghc-8.6.3
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
